@@ -85,6 +85,28 @@ DockerRequirementTypes = (
 """Type union for a CWL v1.x DockerRequirement object."""
 Process = Union[Workflow, CommandLineTool, ExpressionTool, cwl_v1_2.Operation]
 """Type Union for a CWL v1.x Process object."""
+ProcessRequirement = Union[
+    cwl_v1_0.ProcessRequirement,
+    cwl_v1_1.ProcessRequirement,
+    cwl_v1_2.ProcessRequirement,
+]
+"""Type Union for a CWL v1.x ProcessRequirement object."""
+ProcessRequirementTypes = (
+    cwl_v1_0.ProcessRequirement,
+    cwl_v1_1.ProcessRequirement,
+    cwl_v1_2.ProcessRequirement,
+)
+SoftwareRequirement = Union[
+    cwl_v1_0.SoftwareRequirement,
+    cwl_v1_1.SoftwareRequirement,
+    cwl_v1_2.SoftwareRequirement,
+]
+SoftwareRequirementTypes = (
+    cwl_v1_0.SoftwareRequirement,
+    cwl_v1_1.SoftwareRequirement,
+    cwl_v1_2.SoftwareRequirement,
+)
+"""Type union for a CWL v1.x SoftwareRequirement object."""
 ArraySchema = Union[cwl_v1_0.ArraySchema, cwl_v1_1.ArraySchema, cwl_v1_2.ArraySchema]
 """Type Union for a CWL v1.x ArraySchema object."""
 EnumSchema = Union[cwl_v1_0.EnumSchema, cwl_v1_1.EnumSchema, cwl_v1_2.EnumSchema]
@@ -103,6 +125,7 @@ Dirent = Union[cwl_v1_0.Dirent, cwl_v1_1.Dirent, cwl_v1_2.Dirent]
 """Type Union for a CWL v1.x Dirent object."""
 
 _Loader = Union[cwl_v1_0._Loader, cwl_v1_1._Loader, cwl_v1_2._Loader]
+"""Type union for a CWL v1.x _Loader."""
 
 
 def _get_id_from_graph(yaml: MutableMapping[str, Any], id_: Optional[str]) -> Any:
@@ -134,6 +157,7 @@ def cwl_version(yaml: Any) -> Optional[str]:
 def load_document_by_uri(
     path: Union[str, Path],
     loadingOptions: Optional[LoadingOptions] = None,
+    load_all: bool = False,
 ) -> Any:
     """Load a CWL object from a URI or a path."""
     if isinstance(path, str):
@@ -153,7 +177,7 @@ def load_document_by_uri(
         loadingOptions = cwl_v1_2.LoadingOptions(fileuri=baseuri)
 
     doc = loadingOptions.fetcher.fetch_text(real_path)
-    return load_document_by_string(doc, baseuri, loadingOptions, id_)
+    return load_document_by_string(doc, baseuri, loadingOptions, id_, load_all)
 
 
 def load_document(
@@ -161,13 +185,14 @@ def load_document(
     baseuri: Optional[str] = None,
     loadingOptions: Optional[LoadingOptions] = None,
     id_: Optional[str] = None,
+    load_all: bool = False,
 ) -> Any:
     """Load a CWL object from a serialized YAML string or a YAML object."""
     if baseuri is None:
         baseuri = cwl_v1_0.file_uri(os.getcwd()) + "/"
     if isinstance(doc, str):
         return load_document_by_string(doc, baseuri, loadingOptions, id_)
-    return load_document_by_yaml(doc, baseuri, loadingOptions, id_)
+    return load_document_by_yaml(doc, baseuri, loadingOptions, id_, load_all)
 
 
 def load_document_by_string(
@@ -175,11 +200,12 @@ def load_document_by_string(
     uri: str,
     loadingOptions: Optional[LoadingOptions] = None,
     id_: Optional[str] = None,
+    load_all: bool = False,
 ) -> Any:
     """Load a CWL object from a serialized YAML string."""
     yaml = yaml_no_ts()
     result = yaml.load(string)
-    return load_document_by_yaml(result, uri, loadingOptions, id_)
+    return load_document_by_yaml(result, uri, loadingOptions, id_, load_all)
 
 
 def load_document_by_yaml(
@@ -187,10 +213,11 @@ def load_document_by_yaml(
     uri: str,
     loadingOptions: Optional[LoadingOptions] = None,
     id_: Optional[str] = None,
+    load_all: bool = False,
 ) -> Any:
     """Load a CWL object from a YAML object."""
     version = cwl_version(yaml)
-    if "$graph" in yaml:
+    if "$graph" in yaml and not load_all:
         yaml = _get_id_from_graph(yaml, id_)
         yaml["cwlVersion"] = version
     if version == "v1.0":
