@@ -4,15 +4,15 @@ import logging
 from collections import namedtuple
 from typing import IO, Any, Dict, List, MutableSequence, Optional, Tuple, Union, cast
 
+from ruamel import yaml
 from schema_salad.exceptions import ValidationException
 from schema_salad.sourceline import SourceLine
 from schema_salad.utils import aslist, json_dumps
 
 import cwl_utils.parser
-import cwl_utils.parser.cwl_v1_0 as cwl
+import cwl_utils.parser.cwl_v1_2 as cwl
 import cwl_utils.parser.utils
 from cwl_utils.errors import WorkflowException
-from cwl_utils.utils import yaml_dumps
 
 CONTENT_LIMIT: int = 64 * 1024
 
@@ -82,6 +82,15 @@ def _compare_type(type1: Any, type2: Any) -> bool:
         return bool(type1 == type2)
 
 
+def _is_conditional_step(
+    param_to_step: Dict[str, cwl.WorkflowStep], parm_id: str
+) -> bool:
+    if (source_step := param_to_step.get(parm_id)) is not None:
+        if source_step.when is not None:
+            return True
+    return False
+
+
 def can_assign_src_to_sink(src: Any, sink: Any, strict: bool = False) -> bool:
     """
     Check for identical type specifications, ignoring extra keys like inputBinding.
@@ -120,11 +129,15 @@ def can_assign_src_to_sink(src: Any, sink: Any, strict: bool = False) -> bool:
 def check_all_types(
     src_dict: Dict[str, Any],
     sinks: MutableSequence[Union[cwl.WorkflowStepInput, cwl.WorkflowOutputParameter]],
+    param_to_step: Dict[str, cwl.WorkflowStep],
     type_dict: Dict[str, Any],
 ) -> Dict[str, List[SrcSink]]:
     """Given a list of sinks, check if their types match with the types of their sources."""
     validation: Dict[str, List[SrcSink]] = {"warning": [], "exception": []}
     for sink in sinks:
+        extra_message = (
+            "pickValue is %s" % sink.pickValue if sink.pickValue is not None else None
+        )
         if isinstance(sink, cwl.WorkflowOutputParameter):
             sourceName = "outputSource"
             sourceField = sink.outputSource
@@ -138,9 +151,23 @@ def check_all_types(
                 linkMerge = sink.linkMerge or (
                     "merge_nested" if len(sourceField) > 1 else None
                 )
+                if sink.pickValue in ["first_non_null", "the_only_non_null"]:
+                    linkMerge = None
                 srcs_of_sink = []
                 for parm_id in sourceField:
                     srcs_of_sink += [src_dict[parm_id]]
+                    if (
+                        _is_conditional_step(param_to_step, parm_id)
+                        and sink.pickValue is not None
+                    ):
+                        validation["warning"].append(
+                            SrcSink(
+                                src_dict[parm_id],
+                                sink,
+                                linkMerge,
+                                message="Source is from conditional step, but pickValue is not used",
+                            )
+                        )
             else:
                 parm_id = cast(str, sourceField)
                 if parm_id not in src_dict:
@@ -149,6 +176,33 @@ def check_all_types(
                     )
                 srcs_of_sink = [src_dict[parm_id]]
                 linkMerge = None
+                if sink.pickValue is not None:
+                    validation["warning"].append(
+                        SrcSink(
+                            src_dict[parm_id],
+                            sink,
+                            linkMerge,
+                            message="pickValue is used but only a single input source is declared",
+                        )
+                    )
+                if _is_conditional_step(param_to_step, parm_id):
+                    src_typ = aslist(type_dict[srcs_of_sink[0].id])
+                    snk_typ = type_dict[cast(str, sink.id)]
+                    if "null" not in src_typ:
+                        src_typ = ["null"] + cast(List[Any], src_typ)
+                    if (
+                        not isinstance(snk_typ, MutableSequence)
+                        or "null" not in snk_typ
+                    ):
+                        validation["warning"].append(
+                            SrcSink(
+                                src_dict[parm_id],
+                                sink,
+                                linkMerge,
+                                message="Source is from conditional step and may produce `null`",
+                            )
+                        )
+                    type_dict[srcs_of_sink[0].id] = src_typ
             for src in srcs_of_sink:
                 check_result = check_types(
                     type_dict[cast(str, src.id)],
@@ -157,9 +211,13 @@ def check_all_types(
                     getattr(sink, "valueFrom", None),
                 )
                 if check_result == "warning":
-                    validation["warning"].append(SrcSink(src, sink, linkMerge, None))
+                    validation["warning"].append(
+                        SrcSink(src, sink, linkMerge, extra_message)
+                    )
                 elif check_result == "exception":
-                    validation["exception"].append(SrcSink(src, sink, linkMerge, None))
+                    validation["exception"].append(
+                        SrcSink(src, sink, linkMerge, extra_message)
+                    )
     return validation
 
 
@@ -195,22 +253,27 @@ def content_limit_respected_read_bytes(f: IO[bytes]) -> bytes:
     """
     Read file content up to 64 kB as a byte array.
 
-    Truncate content for larger files.
+    Throw exception for larger files (see https://www.commonwl.org/v1.2/Workflow.html#Changelog).
     """
-    return f.read(CONTENT_LIMIT)
+    contents = f.read(CONTENT_LIMIT + 1)
+    if len(contents) > CONTENT_LIMIT:
+        raise WorkflowException(
+            "file is too large, loadContents limited to %d bytes" % CONTENT_LIMIT
+        )
+    return contents
 
 
 def content_limit_respected_read(f: IO[bytes]) -> str:
     """
     Read file content up to 64 kB as an utf-8 encoded string.
 
-    Truncate content for larger files.
+    Throw exception for larger files (see https://www.commonwl.org/v1.2/Workflow.html#Changelog).
     """
     return content_limit_respected_read_bytes(f).decode("utf-8")
 
 
 def convert_stdstreams_to_files(clt: cwl.CommandLineTool) -> None:
-    """Convert stdout and stderr type shortcuts to files."""
+    """Convert stdin, stdout and stderr type shortcuts to files."""
     for out in clt.outputs:
         if out.type == "stdout":
             if out.outputBinding is not None:
@@ -238,6 +301,22 @@ def convert_stdstreams_to_files(clt: cwl.CommandLineTool) -> None:
                 )
             out.type = "File"
             out.outputBinding = cwl.CommandOutputBinding(glob=clt.stderr)
+    for inp in clt.inputs:
+        if inp.type == "stdin":
+            if inp.inputBinding is not None:
+                raise ValidationException(
+                    "Not allowed to specify unputBinding when using stdin shortcut."
+                )
+            if clt.stdin is not None:
+                raise ValidationException(
+                    "Not allowed to specify stdin path when using stdin type shortcut."
+                )
+            else:
+                clt.stdin = (
+                    "$(inputs.%s.path)"
+                    % cast(str, inp.id).rpartition("#")[2].split("/")[-1]
+                )
+                inp.type = "File"
 
 
 def merge_flatten_type(src: Any) -> Any:
@@ -279,12 +358,12 @@ def type_for_step_output(
     step_run = cwl_utils.parser.utils.load_step(step)
     cwl_utils.parser.utils.convert_stdstreams_to_files(step_run)
     if step_run and step_run.outputs:
-        for step_output in step_run.outputs:
+        for output in step_run.outputs:
             if (
-                step_output.id.split("#")[-1].split("/")[-1]
+                output.id.split("#")[-1].split("/")[-1]
                 == sourcename.split("#")[-1].split("/")[-1]
             ):
-                output_type = step_output.type
+                output_type = output.type
                 if step.scatter is not None:
                     if step.scatterMethod == "nested_crossproduct":
                         for _ in range(len(aslist(step.scatter))):
@@ -297,7 +376,7 @@ def type_for_step_output(
     raise ValidationException(
         "param {} not found in {}.".format(
             sourcename,
-            yaml_dumps(cwl.save(step_run)),
+            yaml.main.round_trip_dump(cwl.save(step)),
         )
     )
 
@@ -307,6 +386,7 @@ def type_for_source(
     sourcenames: Union[str, List[str]],
     parent: Optional[cwl.Workflow] = None,
     linkMerge: Optional[str] = None,
+    pickValue: Optional[str] = None,
 ) -> Any:
     """Determine the type for the given sourcenames."""
     scatter_context: List[Optional[Tuple[int, str]]] = []
@@ -323,6 +403,10 @@ def type_for_source(
             new_type = cwl.ArraySchema(items=new_type, type="array")
         elif linkMerge == "merge_flattened":
             new_type = merge_flatten_type(new_type)
+        if pickValue is not None:
+            if isinstance(new_type, cwl.ArraySchema):
+                if pickValue in ["first_non_null", "the_only_non_null"]:
+                    new_type = new_type.items
         return new_type
     new_type = []
     for p, sc in zip(params, scatter_context):
@@ -343,13 +427,16 @@ def type_for_source(
     if len(new_type) == 1:
         new_type = new_type[0]
     if linkMerge == "merge_nested":
-        return cwl.ArraySchema(items=new_type, type="array")
+        new_type = cwl.ArraySchema(items=new_type, type="array")
     elif linkMerge == "merge_flattened":
-        return merge_flatten_type(new_type)
+        new_type = merge_flatten_type(new_type)
     elif isinstance(sourcenames, List) and len(sourcenames) > 1:
-        return cwl.ArraySchema(items=new_type, type="array")
-    else:
-        return new_type
+        new_type = cwl.ArraySchema(items=new_type, type="array")
+    if pickValue is not None:
+        if isinstance(new_type, cwl.ArraySchema):
+            if pickValue in ["first_non_null", "the_only_non_null"]:
+                new_type = new_type.items
+    return new_type
 
 
 def param_for_source_id(
@@ -357,11 +444,11 @@ def param_for_source_id(
     sourcenames: Union[str, List[str]],
     parent: Optional[cwl.Workflow] = None,
     scatter_context: Optional[List[Optional[Tuple[int, str]]]] = None,
-) -> Union[List[cwl.InputParameter], cwl.InputParameter]:
+) -> Union[List[cwl.WorkflowInputParameter], cwl.WorkflowInputParameter]:
     """Find the process input parameter that matches one of the given sourcenames."""
     if isinstance(sourcenames, str):
         sourcenames = [sourcenames]
-    params: List[cwl.InputParameter] = []
+    params: List[cwl.WorkflowInputParameter] = []
     for sourcename in sourcenames:
         if not isinstance(process, cwl.Workflow):
             for param in process.inputs:
@@ -401,26 +488,27 @@ def param_for_source_id(
                                         ):
                                             params.append(output)
                                             if scatter_context is not None:
-                                                if isinstance(step.scatter, str):
-                                                    scatter_context.append(
-                                                        (
-                                                            1,
-                                                            step.scatterMethod
-                                                            or "dotproduct",
+                                                if scatter_context is not None:
+                                                    if isinstance(step.scatter, str):
+                                                        scatter_context.append(
+                                                            (
+                                                                1,
+                                                                step.scatterMethod
+                                                                or "dotproduct",
+                                                            )
                                                         )
-                                                    )
-                                                elif isinstance(
-                                                    step.scatter, MutableSequence
-                                                ):
-                                                    scatter_context.append(
-                                                        (
-                                                            len(step.scatter),
-                                                            step.scatterMethod
-                                                            or "dotproduct",
+                                                    elif isinstance(
+                                                        step.scatter, MutableSequence
+                                                    ):
+                                                        scatter_context.append(
+                                                            (
+                                                                len(step.scatter),
+                                                                step.scatterMethod
+                                                                or "dotproduct",
+                                                            )
                                                         )
-                                                    )
-                                                else:
-                                                    scatter_context.append(None)
+                                                    else:
+                                                        scatter_context.append(None)
     if len(params) == 1:
         return params[0]
     elif len(params) > 1:
@@ -428,7 +516,9 @@ def param_for_source_id(
     raise WorkflowException(
         "param {} not found in {}\n{}.".format(
             sourcename,
-            yaml_dumps(cwl.save(process)),
-            f" or\n {yaml_dumps(cwl.save(parent))}" if parent is not None else "",
+            yaml.main.round_trip_dump(cwl.save(process)),
+            f" or\n {yaml.main.round_trip_dump(cwl.save(parent))}"
+            if parent is not None
+            else "",
         )
     )
